import { __awaiter } from "tslib";
import { consola } from 'consola';
import editJSONFile from 'edit-json-file';
import { downloadTemplate, startShell } from 'giget';
import { relative, resolve } from 'pathe';
import { listAllFiles, rename } from '../utils/fs.js';
import { writeFileWithData } from '../utils/handlebars.js';
import { replaceObjectKeys } from '../utils/lang.js';
import { install } from '../utils/npm.js';
import { runPrompts } from '../utils/prompts.js';
export default {
    action: (dir, options) => __awaiter(void 0, void 0, void 0, function* () {
        const start = Date.now();
        const template = options.seed || options.s || 'gh:genesiscommunitysuccess/blank-app-seed#master';
        let t;
        try {
            t = yield downloadTemplate(template, {
                dir,
            });
        }
        catch (err) {
            if (process.env.DEBUG) {
                throw err;
            }
            consola.error(err.toString());
            process.exit(1);
        }
        consola.info(`Cloned in ${Date.now() - start}ms`);
        const nextSteps = [
            'Install dependencies with `npm run bootstrap`',
            'Start development server with `npm run dev`',
        ];
        consola.log(`✨ Genesis project created using \`${t.name}\` seed. Next steps:`);
        for (const step of nextSteps) {
            consola.log(` › ${step}`);
        }
        const genxPath = relative(process.cwd(), `${t.dir}/.genx`);
        yield install(genxPath, true);
        consola.info(`Seed NPM install done in ${Date.now() - start}ms`);
        const genxConfigPath = resolve(import.meta.url, `${t.dir}/.genx/.genxrc.js`);
        const genxConfig = yield import(genxConfigPath).then((r) => r.default);
        const prompts = genxConfig.prompts();
        const configure = genxConfig.configure();
        const data = yield runPrompts(prompts);
        const utils = {
            editJSONFile,
            writeFileWithData,
            listAllFiles,
            replaceObjectKeys,
            rename,
        };
        const start2 = Date.now();
        data.appName = data.pkgName;
        data.directory = t.dir;
        yield configure(data, utils).catch((e) => {
            consola.error(e);
        });
        consola.info(`Configuration done in ${Date.now() - start2}ms`);
        consola.info(`Total time: ${Date.now() - start}ms`);
        startShell(t.dir);
    }),
};
